@@ -7,20 +7,24 @@
 
 interval <- function(x, a=-Inf, b=Inf)
      {
-     if(a > b) stop("a > b.")
      if(missing(x)) stop("The x argument is required.")
+     if(a > b) stop("a > b.")
      ### Scalar
-     if(is.vector(x) && {length(x) == 1}) x <- max(a,min(b,x))
+     if(is.vector(x) & {length(x) == 1}) x <- max(a, min(b, x))
      ### Vector
-     else if(is.vector(x) && {length(x) > 1}) {
-          x <- ifelse(x < a, a, x)
-          x <- ifelse(x > b, b, x)}
+     else if(is.vector(x) & {length(x) > 1}) {
+          x.num <- which(x < a)
+          x[x.num] <- a
+          x.num <- which(x > b)
+          x[x.num] <- b}
      ### Matrix or Array
      else if(is.array(x)) {
           d <- dim(x)
           x <- as.vector(x)
-          x <- ifelse(x < a, a, x)
-          x <- ifelse(x > b, b, x)
+          x.num <- which(x < a)
+          x[x.num] <- a
+          x.num <- which(x > b)
+          x[x.num] <- b
           x <- array(x, dim=d)}
      return(x)
      }
